#
# spec file for package folks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude libfolks|libfolks-dummy|libfolks-eds|libfolks-telepathy

%define soversion      26
%define module_version 26
%define with_telepathy  1
%define with_zeitgeist  0

Name:           folks
Version:        0.15.9
Release:        1.1
Summary:        Library to create metacontacts from multiple sources
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://telepathy.freedesktop.org/wiki/Folks
Source:         %{name}-%{version}.tar.zst

BuildRequires:  gettext
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  python3-dbusmock
BuildRequires:  readline-devel
BuildRequires:  vala >= 0.22.0.28
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gee-0.8) >= 0.8.6
BuildRequires:  pkgconfig(gobject-2.0) >= 2.44.0
BuildRequires:  pkgconfig(libebook-1.2) >= 3.38.0
BuildRequires:  pkgconfig(libebook-contacts-1.2) >= 3.38.0
BuildRequires:  pkgconfig(libedataserver-1.2) >= 3.38.0
BuildRequires:  pkgconfig(libxml-2.0)
%if %{with_telepathy}
BuildRequires:  pkgconfig(telepathy-glib) >= 0.19.9
%endif
%if %{with_zeitgeist}
BuildRequires:  pkgconfig(zeitgeist-2.0) >= 0.9.14
%endif
Requires:       python3-dbusmock

%description
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

%package -n libfolks%{soversion}
Summary:        Library to create metacontacts from multiple sources
# To make lang package installable
# We assume that future -data packages remain backwards compatible
Group:          System/Libraries
Requires:       folks-data >= %{version}
Provides:       %{name} = %{version}

%description -n libfolks%{soversion}
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

%package data
Summary:        Data files for libfolks, a library to create metacontacts from many sources
Group:          System/Libraries
Obsoletes:      libfolks-data < %{version}
Provides:       libfolks-data = %{version}

%description data
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides mandatory data files for the library to work.

%package -n typelib-1_0-Folks-0_7
Summary:        Introspection bindings for libfolks
Group:          System/Libraries

%description -n typelib-1_0-Folks-0_7
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides the GObject Introspection bindings for libfolks.

%package -n typelib-1_0-FolksEds-0_7
Summary:        Introspection bindings for libfolks-eds
Group:          System/Libraries

%description -n typelib-1_0-FolksEds-0_7
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides the GObject Introspection bindings for libfolks.

%package -n typelib-1_0-FolksTelepathy-0_7
Summary:        Introspection bindings for libfolks-telepathy
Group:          System/Libraries

%description -n typelib-1_0-FolksTelepathy-0_7
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides the GObject Introspection bindings for libfolks.

%package -n libfolks-eds%{soversion}
Summary:        Evolution Data Server backend for libfolks
Group:          System/Libraries
Supplements:    (libfolks%{soversion} and evolution-data-server)

%description -n libfolks-eds%{soversion}
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

%package -n libfolks-telepathy%{soversion}
Summary:        Telepathy backend for libfolks
Group:          System/Libraries

%description -n libfolks-telepathy%{soversion}
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

%package tools
Summary:        Additional utilities related to libfolks
# the folks-import tool is useful for old pidgin users
Group:          Development/Libraries/GNOME
Supplements:    (libfolks1 and pidgin)

%description tools
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides tools based on libfolks, like an importer for Pidgin
metacontacts.

%package devel
Summary:        Development files for libfolks
Group:          Development/Libraries/GNOME
Requires:       libfolks%{soversion} = %{version}
Requires:       libfolks-eds%{soversion} = %{version}
Requires:       libfolks-telepathy%{soversion} = %{version}
Requires:       typelib-1_0-Folks-0_7 = %{version}
Requires:       typelib-1_0-FolksEds-0_7 = %{version}
Requires:       typelib-1_0-FolksTelepathy-0_7 = %{version}

%description devel
libfolks is a library that aggregates people from multiple sources (e.g.
Telepathy connection managers) to create metacontacts.

This package provides the development files.

%lang_package

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}
export CFLAGS="%{optflags} -Wno-error=return-type"
%meson \
%if %{with_zeitgeist}
	-Dzeitgeist=true \
%endif
%if ! %{with_telepathy}
	-Dtelepathy_backend=false \
%endif
	%{nil}
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
# We don't need the gconf -> gsettings convesion tool anymore
# it was not installed in the previous versions and did not
# cause bug reports.
rm %{buildroot}/usr/share/GConf/gsettings/folks.convert
%find_lang folks %{?no_lang_C}

%ldconfig_scriptlets -n libfolks%{soversion}
%ldconfig_scriptlets -n libfolks-eds%{soversion}
%ldconfig_scriptlets -n libfolks-telepathy%{soversion}

%files -n libfolks%{soversion}
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libfolks.so.%{soversion}*
%{_libdir}/libfolks-dummy.so.%{soversion}*
%dir %{_libdir}/folks
%dir %{_libdir}/folks/%{module_version}
%dir %{_libdir}/folks/%{module_version}/backends
%{_libdir}/folks/%{module_version}/backends/bluez/
%{_libdir}/folks/%{module_version}/backends/dummy/
%{_libdir}/folks/%{module_version}/backends/key-file/
%{_libdir}/folks/%{module_version}/backends/ofono/

%files data
%{_datadir}/glib-2.0/schemas/org.freedesktop.folks.gschema.xml

%files -n typelib-1_0-Folks-0_7
%{_libdir}/girepository-1.0/Folks-0.7.typelib
%{_libdir}/girepository-1.0/FolksDummy-0.7.typelib

%files -n typelib-1_0-FolksEds-0_7
%{_libdir}/girepository-1.0/FolksEds-0.7.typelib

%files -n libfolks-eds%{soversion}
%{_libdir}/libfolks-eds.so.%{soversion}*
%dir %{_libdir}/folks/%{module_version}/backends/eds
%{_libdir}/folks/%{module_version}/backends/eds/eds.so

%if %{with_telepathy}
%files -n typelib-1_0-FolksTelepathy-0_7
%{_libdir}/girepository-1.0/FolksTelepathy-0.7.typelib

%files -n libfolks-telepathy%{soversion}
%{_libdir}/libfolks-telepathy.so.%{soversion}*
%dir %{_libdir}/folks/%{module_version}/backends/telepathy
%{_libdir}/folks/%{module_version}/backends/telepathy/telepathy.so
%endif

%files tools
%{_bindir}/folks-import
%{_bindir}/folks-inspect

%files devel
%{_includedir}/folks/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/Folks-0.7.gir
%{_datadir}/gir-1.0/FolksDummy-0.7.gir
%{_datadir}/gir-1.0/FolksEds-0.7.gir
%if %{with_telepathy}
%{_datadir}/gir-1.0/FolksTelepathy-0.7.gir
%{_datadir}/vala/vapi/folks-telepathy.*
%endif
%{_datadir}/vala/vapi/folks.*
%{_datadir}/vala/vapi/folks-dummy.*
%{_datadir}/vala/vapi/folks-eds.*

%files lang -f %{name}.lang

%changelog
* Mon Mar 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.15.9:
  + simple-query: normalize phone numbers in search.
  + Updated translations.
* Sun Mar 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.15.8:
  + Major changes:
  - simple-query: Avoid some silly string copies.
  - Lots of translation updates.
  + Bugs fixed:
  - bluez: Follow breaking API change in dbusmock.
* Wed Feb 28 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.15.7+7:
  + build: add missing API declaration -include to dummy and EDS
    backends.
  + Revert "tests/bluez: Follow PairDevice() API change"
  + Updated translations.
- Pass -Wno-error=return-type to CFLAGS: new meson version no
  longer hides the errors/warnings, but vala is not yet better at
  creating C code.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.15.7:
  + Major changes:
  - Add .editorconfig file.
  - Lots of translation updates.
  + Bugs fixed:
  - bluez: Fix invalid ownership of property accessors in Device
    interface.
  - tests/telepathy: Use shared_library() to fix g-ir-scanner
    which expects proper library.
* Tue Mar  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.15.6:
  + Major changes:
  - Projects should be able to use the typelib-based bindings
  - sysprof is now used for profiling
  - Lots of translation updates
  - Several smaller Meson changes
  + Bugs fixed:
  - folks-generics: Add missing generic type argument
  - tests/bluez: Follow PairDevice API change in python-dbusmock
- Add global requires_exclude
  libfolks|libfolks-dummy|libfolks-eds|libfolks-telepathy remove
  wrong requires in typelibs.
* Wed Mar 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.15.5:
  + Bugs fixed: vapi: Add missing generic type argument.
- Drop glib2_gsettings_schema_requires macro from folks-data
  sub-package, no longer needed.
- Drop c44d8e323affd7f1043f300f3325b358cd5b5f0b.patch: Fixed
  upstream.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add c44d8e323affd7f1043f300f3325b358cd5b5f0b.patch:
  folks-generics: Add missing generic type argument.
- Update our Supplements to current standard.
- Use ldconfig_scriptlets macro for post(un) handling.
* Tue Jan 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.15.4:
  + Bugs fixed:
  - Fix docs build against newer eds version.
  - Fix build against newer eds version.
  - Remove volatile keyword from tests.
* Fri Nov  5 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Require libfolks-telepathy%%{soversion} from the -devel package:
  we install the .so symlink and must thus guarantee to have the
  link target present too.
* Fri Aug  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.15.3:
  + Fix build against newer eds version.
- Changes from version 0.15.2:
  + Fixed build errors after API version bump.
  + Fixed gtk-doc errors due to missing version entities.
- Changes from version 0.15.1:
  + Dependencies:
  - No more dependencies on libtracker
  - GLib minimal requirement: 0.58
  - E-D-S minimal requirement: 3.38
  + Major changes:
  - This release drops the Tracker backend (along with it's
    dependencies).
  - A selection of (small) performance improvements.
  - Auto-generation and deployment of the docs using CI.
- Drop conditional pkgconfig(tracker-sparql-2.0) BuildRequires, no
  longer needed, nor used. Following this, drop sub-packages
  typelib-1_0-FolksTracker-0_6 and libfolks-tracker25.
- Bump soversion and module version following upstream changes.
- Rename sub-packages (typelibs) following api/abi bump.
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Enable telepathy support again: set with_telepathy to 1.
* Wed Feb  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Allow to enable/disable telepathy integration using
  with_telepathy: currently set to 0, as build with new vala fails.
  Considering that telepathy is not really maintained anymore,
  there seems little chance for a fix.
* Wed Nov 11 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix dependency of the devel project in case of tracker being
  disabled: conditionally require libfolks-tracker25.
* Mon Sep  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Disable tracker backend for the time being: not compatible to
  Tracker 3.
* Wed Mar 11 2020 bjorn.lie@gmail.com
- Update to version 0.14.0:
  + Updated translations.
- Module_version is now 46.
- Rename sub-package libfolks-data to folks-data, and add Obsoletes
  and Provides libfolks-data to ease upgrades for our end-users.
  Eliminates rpm-lint warning.
* Tue Feb  4 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.13.2:
  + Drop python2 dependency.
  + Use the key-file backend to link personas.
  + Automatically pick the correct E-D-S AddressBook version (using
    pkgconfig).
  + GSettings conversion tool no longer installed.
  + Build failure with meson-0.53.0.
- Drop folks-meson-0.53.patch: fixed upstream.
- Add python3-dbusmock BuildRequires and Requires: the dependency
  is not new, but the build system now checks for it and it made
  apparent that we forgot to add this in the past.
* Thu Jan 23 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend folks-lang: the -lang package has respective
  supplements to have smarter decision when to be installed.
* Thu Jan 23 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add folks-meson-0.53.patch: Fix build with meson 0.53.
  py_installation.dependency() is not meant to check if python
  modules are present, but add a dependency on python.
* Fri Sep  6 2019 luke@ljones.dev
- Disable lto in build due to lto causing segfault in Geary.
* Wed Sep  4 2019 mgorse@suse.com
- Update to version 0.13.1:
  + Remove libsocialweb backend.
- Changes in version 0.12.1:
  + Disabled tests that were failing to be able to build a tarball.
- Changes in version 0.12.0:
  + Dropped depedency on libvaladoc (we now use the binary
    directly).
  + Bumped minimal GLib version to 2.44.
  + Folks is now being built using meson.
  + The autotools build definition was dropped.
  + Dropped support for building without vala.
  + Migrated to the GNOME GitLab and now use a CI-backed workflow.
  + Moved from intltool to gettext.
  + Various fixes for warnings.
  + Lots of translation updates.
  + Bugs fixed:
  - Bug 784544 - Fatal error building git master.
  - Bug 739997 - Crash when selecting contact.
  - Bug 792238 - PotentialMatch: don't rely on null-terminated
    string.
  - Bug 792567 - Individual.display_name: don't fallback on
    persona's display_id if it equals the IID.
- Switch to meson.
- Drop intltool dependency. Depend on gettext..
- Drop folks-tracker.2.0.patch: fixed upstream.
- Module_version is now 45.
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Drop post(un) handling of glib2_gsettings_schema_post(un) for
  libfolks-data subpackage, no longer needed.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Sep 14 2017 fezhang@suse.com
- Drop build support of deprecated libsocialweb backend.
* Fri Sep  8 2017 jengelh@inai.de
- Update summaries. Trim %%if/%%endif markers for package
  declarations that are idempotent.
* Fri Jul 21 2017 zaitor@opensuse.org
- Replace pkgconfig(tracker-sparql-1.0) with
  pkgconfig(tracker-sparql-2.0) BuildRequires.
- Add folks-tracker.2.0.patch: Reference Tracker-2.0 from the .gir
  file.
* Mon Jul  3 2017 zaitor@opensuse.org
- Update to version 0.11.4:
  + Various fixes for Vala compiler and VAPI changes in upstream
    projects.
  + Remove redundant locking.
  + Disable unknown BlueZ devices by default; BlueZ devices must
    now be explicitly enabled via a configuration file before they
    will be queried for personas.
  + Fix build with latest versions of valadoc.
  + Bugs fixed: bgo#781485, bgo#720274, bgo#778005, bgo#773011.
* Thu Mar 16 2017 dimstar@opensuse.org
- Dummy changelog - fool repo-checker in seeing this is rebuilt.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 0.11.3:
  + Various small code fixes for newer Vala versions.
  + Bugs fixed: bgo#758741, bgo#761192.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sat Nov 28 2015 zaitor@opensuse.org
- Update to version 0.11.2:
  + Various EDS unit test fixes, improvements and simplifications.
  + Improve Telepathy error handling on connection failure of a CM
    to avoid timeouts.
  + Bugs fixed: bgo#751044.
  + Updated translations.
* Thu Sep 24 2015 dimstar@opensuse.org
- Dummy change: rebuild against evolution-data-server 3.18.0.
* Tue May 26 2015 zaitor@opensuse.org
- Update to version 0.11.1:
  + Usability fixes in folks-inspect.
  + Various EDS unit test fixes.
  + A few race condition fixes in the EDS backend.
  + Bugs fixed: bgo#646808.
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 0.11.0:
  + Major changes:
  - The --enable-tests configure option has been renamed to
  - -enable-modular-tests.
  - Installed tests are now supported using
  - -enable-installed-tests.
  - Add a vCard-like ExtendedInfo interface.
  - Upgrade to new EDS address book timeout API.
  - Add search-based retrieval of Individuals.
  + Bugs fixed:
  - bgo#641211: Add arbitrary-field interface for applications
    to store trivial per-person data.
  - bgo#743398: Add support for installed-tests.
  - bgo#743934: FTBFS after EDS commit 884fb8d8.
  - bgo#646808: Add search-based retrieval.
  + Various API changes.
- Bump module_version to 43, following upstream.
* Wed Jan 21 2015 zaitor@opensuse.org
- Update to version 0.10.1:
  + Updated translations.
* Fri Sep 12 2014 zaitor@opensuse.org
- Update to version 0.10.0:
  + Remove useless use of the avatar cache in the EDS backend.
  + Listen for primary store changes from GSettings.
  + Bugs fixed: bgo#697695, bgo#731470, bgo#728520.
- Add pkgconfig(tracker-sparql-1.0) BuildRequires and pass
  - -enable-tracker-backend to configure in order to build the
  tracker backend.
- Following above changes, add new sub-packages libfolks-tracker
  and typelib-1_0-FolksTracker-0_6, and handle these in
  post/postun.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 0.9.8:
  + Fix loading backends on distributions which install software in
    loop mounted file systems, such as Tinycorelinux.
  + Bugs fixed: bgo#732244, bgo#733891.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 0.9.7.1:
  + Major changes:
  - Ensure Telepathy VAPI files are built after being cleaned.
  - Rebuild distributed Telepathy VAPI files to be compatible
    with Vala < 0.26.
  + Bugs fixed: bgo#732080.
- Changes from version 0.9.7:
  + Major changes:
  - Add a dummy backend.
  - Vast numbers of fixes to the unit tests.
  - Improvements to how Personas are transferred between
    Individuals.
  - Many build system cleanups.
  - New website (https://wiki.gnome.org/Projects/Folks).
  - Allow backend libraries to have separate LT versions from the
    core library.
  - Performance improvements in the BlueZ backend.
  - Test suite for the BlueZ backend using python-dbusmock.
  + Bugs fixed: bgo#648811, bgo#651672, bgo#705742, bgo#711544,
    bgo#711827, bgo#712274, bgo#720707, bgo#722335, bgo#722579,
    bgo#722892, bgo#723054, bgo#723187, bgo#723540, bgo#724058,
    bgo#724339, bgo#724591, bgo#724809, bgo#726787, bgo#726973,
    bgo#726980, bgo#727405, bgo#727944, bgo#730201, bgo#731175,
    bgo#731325, bgo#731464.
- Drop folks-bnc855848-individual-crash.patch: fixed upstream.
- Bump module_version to 42, following upstream.
* Mon Aug 18 2014 fcrozat@suse.com
- Disable libsocialweb support after 13.1, it is no longer
  supported (bnc#892161).
* Mon Aug 18 2014 fcrozat@suse.com
- Disable libsocialweb support for SLE12, it is no longer supported
  (bnc#892161).
* Fri Apr 11 2014 dimstar@opensuse.org
- Introduce with_zeitgeist defines (currently set to 0) to easily
  switch Zeitgeist integration on and off. At this moment, it is
  crashing empathy on startup if switched on.
* Mon Jan 27 2014 federico@suse.com
- Added folks-bnc855848-individual-crash.patch to fix bnc#855848.
  Empathy would crash when using IRC channels; this fixes the crash.
* Wed Nov  6 2013 dimstar@opensuse.org
- Update to version 0.9.6:
  + Major changes:
  - Add a BlueZ backend.
  - Use Vala to generate GIR files, fixing a number of bugs.
  - Various build system and testing improvements.
  + Avoid useless string copies when normalizing phone numbers.
  + Bugs fixed: bgo#706683, bgo#706826, bgo#706857, bgo#705608,
    bgo#697262, bgo#705403, bgo#679826, bgo#709674, bgo#697209,
    bgo#710178, bgo#682698, bgo#710869, bgo#708059, bgo#685848,
    bgo#711403, bgo#711406.
- Do not pass --enable-vala to configure: the tarball has been
  prepared with a recent enough version of vala, which we do not
  have available yet (version 0.22.0.28).
* Tue Aug 27 2013 dimstar@opensuse.org
- Update to version 0.9.5:
  + Multiple IndividualAggregator instances are now not officially
    supported.
  + Bugs fixed: bgo#705289, bgo#706532.
- Change module_version defines to 41.
- Drop folks-return-value.patch: fixed upstream.
* Fri Aug  2 2013 dimstar@opensuse.org
- Update to version 0.9.4:
  + Fatal warnings are now turned off when distchecking.
  + EDS dependency has been bumped to 3.9.1 to fix a Vala binding
    issue.
  + Various API changes.
  + Bugs fixed: bgo#699865, bgo#703402, bgo#703450, bgo#703514,
    bgo#703709, bgo#703830, bgo#704922, bgo#705196, bgo#703516,
    bgo#701850.
- Pass --disable-fatal-warnings to configure to be less strict.
- Change module_version defines to 40.
- Create new subpackage for the new typelibs:
  + typelib-1_0-FolksEds-0_6
  + typelib-1_0-FolksLibsocialweb-0_6
  + typelib-1_0-FolksTelepathy-0_6.
- Add folks-return-value.patch: return a value from
  folks_small_set_copy().
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 0.9.3:
  + Bugs fixed: bgo#683873, bgo#686715, bgo#698890, bgo#702490.
- Changes from version 0.9.2:
  + API changes: Add LocationDetails interface to specify a Persona
    or Individual's geographical location.
  + Bugs fixed: bgo#693333, bgo#694883, bgo#695628, bgo#695648,
    bgo#695719, bgo#695381, bgo#696179, bgo#682903, bgo#694385,
    bgo#700253.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 0.9.1:
  + Fix build with e-d-s master (bgo#694049).
- Changes from version 0.9.0:
  + Added an ofono backend.
  + Ported to libgee 0.8.x
  + Various API changes.
  + Bugs fixed: bgo#682941, bgo#685084, bgo#686056, bgo#685250,
    bgo#686674, bgo#686506, bgo#686693, bgo#685401, bgo#687050,
    bgo#686673, bgo#688834, bgo#688923, bgo#689146, bgo#689859,
    bgo#677633, bgo#685992, bgo#690989, bgo#690990, bgo#690876,
    bgo#691167, bgo#686695, bgo#691382, bgo#691923, bgo#692122,
    bgo#693435, bgo#673918, bgo#692951.
* Thu Oct  4 2012 dimstar@opensuse.org
- Update to version 0.8.0:
  + Bugs fixed: bgo#684014, bgo#683390, bgo#672709, bgo#684954
  + Updated translations.
- Remove hack to remove x-bit from AUTHORS: fixed upstream.
* Wed Sep 12 2012 vuntz@opensuse.org
- Update to version 0.7.4.1:
  + Re-roll release with correct soversion.
- Changes from version 0.7.4:
  + Bugs fixed: bgo#664072, bgo#680335, bgo#681164, bgo#681346,
    bgo#681420, bgo#681476, bgo#681726, bgo#682346, bgo#682572,
    bgo#682719, bgo#682809, bgo#683093, bgo#683267, bgo#683319,
    bgo#683390, bgo#683452.
- Drop folks-new_vala.patch: fixed upstream.
- Bump module_version to 37, following upstream changes.
* Sun Jul 29 2012 dimstar@opensuse.org
- Update to version 0.7.3:
  + bgo#629537: Support anti-linking
  + Bugs fixed: bgo#652637, bgo#657456, bgo#660128, bgo#660236,
    bgo#669158, bgo#674611, bgo#675223, bgo#678696, bgo#679116,
    bgo#679618.
- Bump module_version to 36, following upstreams changes.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.7.2.2:
  + Minor fixes.
  + Updated translations.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 0.7.2.1:
  + bgo#678734: Add profiling API
  + Bugs fixed: bgo#677166, bgo#678474, bgo#678781, bgo#678811,
    bgo#679020.
- Bump module_version to 35, following upstreams changes.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 0.7.1:
  + Port Folks to GSettings (bgo#647909)
  + Bugs fixed: bgo#627403, bgo#663890, bgo#672709, bgo#674256,
    bgo#675121, bgo#675292, bgo#676023.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed after
  the port to GSettings.
- Add pkgconfig(zeitgeist-1.0) BuildRequires: new dependency.
- Split a libfolks-data package, which contains the glib schema and
  GConf conversion information. This package is required by
  libfolks, but is split in order to allow parallel installation of
  multiple libfolks<n> packages.
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 0.7.0:
  + Folks now uses the Connection.ContactList Telepathy spec
    instead of the deprecated Channel.ContactList. This means
    legacy Connection Managers (notably telepathy-butterfly) are
    not supported any more.
  + API Changes:
  - Add IndividualAggregator.look_up_individual().
  + Bugs fixed:
  - bgo#630822: Support Connection.Interface.ContactList API.
  - bgo#658576: Need API to get a FolksIndividual from his ID.
  - bgo#671662: Renamed alias of Facebook contact is not saved.
- Bump module_version define to 33, following upstream change.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 0.6.9:
  + Forced quiescence timeout has been increased to 30s (from 5s)
  + Updates and improvements to the Telepathy backend test suite
  + Bugs fixed: bgo#672980.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 0.6.8:
  + FOLKS_DEBUG has been removed in favour of G_MESSAGES_DEBUG (and
    the bug where folks would set G_MESSAGES_DEBUG for any process
    linked to it has been fixed)
  + A --disable-fatal-warnings configure flag has been added for
    non-developers
  + Update favourite status of EDS contacts with membership of the
    ‘Starred in Android’ Google Contacts group
  + Improvements to linking suggestions (potential matches)
  + Improvements to folks-inspect to make it a good command line
    citizen
  + Small API addition.
  + Bugs fixed: bgo#660235, bgo#661490, bgo#669984, bgo#670191,
    bgo#670347, bgo#670348, bgo#670523, bgo#670872, bgo#671499,
    bgo#671714, bgo#671900, bgo#672373, bgo#672381.
- Drop folks-libsocialweb-quiescent.patch: fixed upstream.
- Bump module_version define to 32, following upstream change.
* Mon Mar  5 2012 vuntz@opensuse.org
- Add folks-libsocialweb-quiescent.patch: fix issue where the
  libsocialweb backend caused empathy to not display contacts in
  the contact list.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 0.6.7:
  + Small API additions.
  + Bugs fixed: bgo#657063, bgo#659610, bgo#666310, bgo#666528,
    bgo#666540, bgo#667410, bgo#667535, bgo#668415, bgo#670196.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Bump module_version define to 31, following upstream change.
* Wed Dec 21 2011 vuntz@opensuse.org
- Split typelib file into typelib-1_0-Folks-0_6 subpackage.
- Add typelib-1_0-Folks-0_6 Requires to devel subpackage.
* Wed Dec 14 2011 dimstar@opensuse.org
- Update to version 0.6.6:
  + Various API changes
  + Bugs fixed: bgo#664158, bgo#663889, bgo#665039, bgo#665728,
    bgo#665692, bgo#665376.
- Replace License tag with spdx identifier (LGPL-2.1+).
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
- Bump module_version define to 30, following upstream change.
* Tue Nov 15 2011 vuntz@opensuse.org
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.6.5:
  + Add favourites support to EDS backend.
  + Behavior changes:
  - PostalAddress.equal() now ignores PostalAddress.uid
  - NoteFieldDetails.equal() now ignores NoteFieldDetails.uid
  + Small API additions and deprecations.
  + Bugs fixed: bgo#662285, bgo#662433, bgo#660908, bgo#662770,
    bgo#662616, bgo#662274, bgo#662314, bgo#663798, bgo#659585.
- Bump module_version define to 29, following upstream change.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 0.6.4.1:
  + Bugs fixed: bgo#662095.
- Changes from version 0.6.4:
  + Small API additions.
  + Bugs fixed: bgo#660217, bgo#657602, bgo#660937, bgo#661475.
- Bump module_version define, following upstream change.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 0.6.3.2:
  + Bugs fixed: bgo#660140, bgo#659041, bgo#660051.
* Sat Sep 24 2011 vuntz@opensuse.org
- Update to version 0.6.3.1:
  + Bugs fixed: bgo#658631, bgo#658002, bgo#659737.
* Mon Sep 19 2011 vuntz@opensuse.org
- Update to version 0.6.3:
  + Major changes:
  - Cleanup of the definition of "writeable" which involves a
    couple of API deprecations and additions, and some internal
    re-working.
  - Beginnings of standardising TYPE values for
    AbstractFieldDetails
  + Several API changes, see NEWS for details.
  + Bugs fixed: bgo#658631, bgo#658331, bgo#658874, bgo#658730,
    bgo#633781, bgo#657142, bgo#658002, bgo#657065, bgo#658323,
    bgo#659095, bgo#659128, bgo#657141, bgo#658531, bgo#658328,
    bgo#646847, bgo#658161, bgo#657738, bgo#653623.
- Bump the module_version macro to reflect upstream change.
* Thu Sep  8 2011 vuntz@opensuse.org
- Update to version 0.6.2.1:
  + Bugs fixed: bgo#658580.
* Thu Sep  8 2011 vuntz@opensuse.org
- Update to version 0.6.2:
  + Several API changes, see NEWS for details.
  + Bugs fixed: bgo#645056, bgo#653777, bgo#657635, bgo#657510,
    bgo#656184, bgo#657971, bgo#657789, bgo#657282, bgo#657969,
    bgo#657783, bgo#658411, bgo#656689.
- Define a soversion macro so we can differentiate the major
  version of the libraries and the version used to locate backends.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 0.6.1:
  + Bugs fixed: bgo#656659, bgo#655374, bgo#657067, bgo#657332.
- Change vala-devel BuildRequires to vala, as we only need the vala
  compiler.
* Sat Aug 13 2011 dimstar@opensuse.org
- Update to version 0.6.0:
  + Several API changes, see NEWS for details.
  + Add EDS backend.
  + Allow writing to properties of all personas.
  + Add support for presence status from Telepathy.
  + Bugs fixed: bgo#649925, bgo#646244, bgo#652463, bgo#652434,
    bgo#648071, bgo#652472, bgo#629716, bgo#652660, bgo#652449,
    bgo#653325, bgo#653746, bgo#638281, bgo#654509, bgo#652048,
    bgo#652425, bgo#645549, bgo#650422, bgo#655019, bgo#650414,
    bgo#652643, bgo#655510, bgo#654907, bgo#655745, bgo#649296,
    bgo#652657, bgo#655008, bgo#653619, bgo#653679, bgo#653680,
    bgo#655917, bgo#655374, bgo#655919, bgo#655920, bgo#653682,
    bgo#655921, bgo#655922, bgo#648818, bgo#655609.
- Enable the new E-D-S Backend:
  + Add pkgconfig(libebook-1.2) and pkgconfig(libedataserver-1.2)
    BuildRequires.
  + Pass --enable-eds-backend to configure.
  + Split out a libfolks-eds package.
- Drop folks-fix-build.patch: fixed upstream.
* Fri Jul  1 2011 vuntz@opensuse.org
- Add folks-fix-build.patch to fix the build. Taken from git.
* Fri Jun  3 2011 dimstar@opensuse.org
- Update to version 0.5.2:
  + bgo#650067: Tracker backend warns when setting a NULL avatar
    (ie, unsetting the avatar)
  + bgo#650268: build failure: "--vapidir=.: command not found"
* Thu May 26 2011 vuntz@opensuse.org
- Add pkgconfig(libsocialweb-client) BuildRequires to build the
  libsocialweb backend, and create a libfolks-libsocialweb24
  subpackage.
- Add readline-devel BuildRequires to build inspector tool
  (folks-inspect).
- Add Url tag.
* Tue May 17 2011 dimstar@opensuse.org
- Update to version 0.5.1:
  + Add gobject-introspection support.
  + Several API changes, see NEWS for details.
  + Bugs fixed: bgo#645388, bgo#647562, bgo#647121, bgo#645684,
    bgo#640092, bgo#648161, bgo#645186, bgo#648533, bgo#649790,
    bgo#649088
* Thu May  5 2011 dimstar@opensuse.org
- Update to version 0.5.0:
  + Major changes:
  - Add support to change primary (writeable) store either via
    GConf or an env variable (bgo#645441).
  - Add a tracker backend
  - Add a libsocialweb backend
  - Add the potential matches API
    GConf or an env variable (bgo#645441).
  + Several API additions.
  + Bugs fixed: bgo#644968, bgo#644966, bgo#644527, bgo#645430,
    bgo#645411, bgo#645475, bgo#645570, bgo#645989, bgo#645413,
    bgo#645441, bgo#638280, bgo#646944, bgo#644867, bgo#647168,
    bgo#646831, bgo#647298, bgo#646948.
- Add pkgconfig(gconf-2.0) BuildRequires.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 0.4.3:
  + Bug fixes: bgo#645680, bgo#647562, bgo#647121.
* Mon Apr  4 2011 dimstar@opensuse.org
- BuildRequire vala-devel instead of vala-unstable (vala 0.12 has
  been released).
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 0.4.2:
  + fdo#645430: folks-inspect: Use LinkedHashSet to access
    im-addresses.
  + fdo#645411: folks-import segfaults on startup
  + Crasher when removing Personas
- Changes from version 0.4.1:
  + Bugs fixed:
  - fdo#644968: _update_phone_numbers() needs to create copies
    of each List<FieldDetails>
  - fdo#644966: _update_emails () needs to create copies of each
    List<FieldDetails>
  - Crasher when reconnecting a Telepathy account
* Wed Mar 16 2011 fcrozat@novell.com
- Update to version 0.4.0:
  + API changes:
  - Add RoleDetails interface
  - Add BirthdayDetails interface
  - Add NoteDetails interface
  - Add PostalAddressDetails interface
  - Rename Aliasable -> AliasDetails
  - Rename AvatarOwner -> AvatarDetails
  - Rename Emailable -> EmailDetails
  - Rename Favouritable -> FavouriteDetails
  - Rename GenderOwner -> GenderDetails
  - Rename Groupable -> GroupDetails
  - Rename IMable -> ImDetails
  - Rename NameOwner -> NameDetails
  - Rename Phoneable -> PhoneDetails
  - Rename PresenceOwner -> PresenceDetails
  - Rename Urlable -> UrlDetails
  + Bugs fixed: fdo#642351, fdo#643241, fdo#643247, fdo#643201,
    fdo#642866, fdo#642861, fdo#642493, fdo#642500, fdo#642501,
    fdo#641210, fdo#643956, fdo#643954, fdo#643955, fdo#643957,
    fdo#644457, fdo#644165
- Bump module_version to 22.
* Thu Mar  3 2011 vuntz@opensuse.org
- Create a lang package.
- Move the keyfile backend to libfolks instead of
  libfolks-telepathy.
* Wed Mar  2 2011 fcrozat@novell.com
- Update to version 0.3.6:
  + This is just a repackaging of libfolks 0.3.5 with some
    documentation comment version numbers fixed.
- Changes from version 0.3.5:
  + Major changes:
  - Various API breaks and improvements, especially in the
    IndividualAggregator
  - Add various new interfaces: NameOwner, FieldDetails, Urlable,
    GenderOwner, Phoneable and Emailable
  + Bugs fixed: bgo#640901, bgo#641780, bgo#629078, bgo#642036.
- Changes from version 0.3.4:
  + Major changes:
  - Add folks-inspect tool
  - The use of the new LinkedHashSet type in the API may make
    libgee a requirement for some clients (to take full advantage
    of its class lineage).
  + Bugs fixed: bgo#637240, bgo#638311, bgo#629083, bgo#629075,
    bgo#638609, bgo#639195, bgo#639113, bgo#639742, bgo#640213,
    bgo#627397.
- Changes from version 0.3.3:
  + Major changes:
  - Fix some minor leaks
  - Add support for building gtk-doc documentation for the C API
  - Fix some related documentation problems
  - Fix some Vala problems caused by differences between Vala
    0.10 and 0.12
  - Finish off renaming interfaces (this is an API break; see
    below)
  - Don't trust personas from IRC
  - Handle invalid IM addresses more gracefully than with an
    assertion failure
  - Fix a linking problem with the user's individual when going
    offline which could lead to infinite loops
  + Bugs fixed: bgo#635178, bgo#635649, bgo#635703, bgo#635823,
    bgo#636251, bgo#629526, bgo#627397, bgo#636714, bgo#637136.
- Changes from version 0.3.2:
  + Major changes:
  - BackendStore.load_backends() now (un)loads backends which
    have been (dis|en)abled since the last call
  - FOLKS_BACKEND_DIR has been replaced by FOLKS_BACKEND_PATH. It
    accepts any number of files and directories, separated by :
  - Significantly clean up the build system
  + Bugs fixed: bgo#629081, bgo#629862, bgo#628883, bgo#633718,
    bgo#633080.
- Changes from version 0.3.1:
  + Major changes:
  - Tpf.Persona.contact is now guaranteed to have the client type
    feature
  + Bugs fixed: bgo#630431, bgo#631864, bgo#632096, bgo#632163,
    bgo#632564.
- Changes from version 0.3.0:
  + Major changes:
  - Fixed some linking problems
  - Added some missing documentation
  - Fixed build problems introduced by switching to
    gobject-introspection 0.9.6 (i.e. GIR format 1.2)
  - Ensured IM addresses are normalised before being compared
  - Made the folks-import build optional through a configure
    argument
  - Added support for a "self" individual
  - Added support for generating and installing Devhelp format
    documentation
  - BackendStore.load_backends and the prepare() functions are
    now idempotent
  - Tpf.Persona.contact is now guaranteed to have the avatar
    token and data features
  - Tpf.Persona.contact is now guaranteed to have the
    capabilities feature
  + Bugs fixed: bgo#629452, bgo#626008, bgo#629311, bgo#629644,
    bgo#629666, bgo#628970, bgo#629096, bgo#627402, bgo#629642,
    bgo#629643, bgo#629006, bgo#629331, bgo#629008, bgo#630347.
- Add intltool BuildRequires.
- Change vala-devel BuildRequires to vala-unstable: we don't need
  the devel files, and we need a newer vala.
- Pass --enable-vala to configure.
- Rename libfolks1 and libfolks-telepathy1 to follow library
  soversion changes.
* Wed Nov 17 2010 vuntz@opensuse.org
- Define a module_version variable for easier updates: upstream
  changes the internal module version at each release, and it's
  reflected in where files get installed.
* Wed Nov 10 2010 coolo@novell.com
- Own directories for our files.
* Fri Oct 29 2010 vuntz@opensuse.org
- Update to version 0.2.1:
  + bgo#629642: individuals-changed emitted in the wrong order
  + bgo#631864: Crash when empathy disconnects
  + bgo#632564: assertion `EMPATHY_IS_CONTACT (contact)' failed in
    individual_store_contact_sort
  + bgo#632163: Folks key-file backend needs a way to point to a
    specific .ini file
- Rename libfolks0 to libfolks1 and libfolks-telepathy0 to
  libfolks-telepathy1, following soversion change.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 0.2.0:
  + Build fixes for GIR 1.2 and Vala 0.10.
  + Various linking fixes
  + Normalize IM addresses written to the writeable backend
  + Allow building the folks-import tool to be disabled
* Sat Sep 11 2010 vuntz@opensuse.org
- Update to version 0.1.17:
  + Add the framework for a test suite
  + Add a test of an individual's properties
  + Build clean-ups
  + Add generated C files to GITIGNOREFILES
  + Don't allow setting a Kf.Persona's alias to its current value
  + Don't save the key file when loading Personas' aliases
  + Add more debugging for aliases
  + Fix saving the key file when it contains multi-byte characters
  + Warn on key file parse errors, rather than explode
  + Notify of Tpf.PersonaStore's Personas being removed when
    disabling account
  + bgo#628853: hangs if there's no relationships.ini file
  + Block flushing of Kf.PersonaStore on any pending file
    operations
  + bgo#629084: add a folks-import tool, including Pidgin support
- Add pkgconfig(libxml-2.0) BuildRequires to build the folks-import
  tool.
- Create a tools subpackage for folks-import, with a Supplements
  for packageand(libfolks0:pidgin), since it will be useful for old
  pidgin users.
* Wed Sep  1 2010 dimstar@opensuse.org
- Update to 0.1.16:
  + bgo#628343: Add an environment variable to disable linking
  + Depend on libgee < 0.7, due to API break.
* Fri Aug 27 2010 vuntz@opensuse.org
- Update to version 0.1.15:
  + Various introspection and parallel build fixes
  + Ensure duplicate Individuals don't make their way into various
    properties
  + Make gobject-introspection a hard requirement
  + Add an Individual.personas_changed signal to allow more
    efficient client code
  + Add trust levels to Individuals to allow the UI to determine
    whether to allow linking to them
  + Fix alias writing to the backends and improve selection of
    aliases for Individuals
* Fri Aug 20 2010 dimstar@opensuse.org
- Update to version 0.1.14.1:
  + Bump vala version requirement.
  + Depend upon a released version of Vala.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 0.1.14:
  + Fix calls to deprecated Gee.Map.remove()
  + Build tp-lowlevel via gobject-introspection
  + Use gen-introspect-0.10 instead of gen-introspect
  + Detect Vala by special automake macro, not .pc file.
- Replace pkgconfig(vala-1.0) BuildRequires with vala-devel.
- Remove pkgconfig(telepathy-vala) BuildRequires.
* Wed Aug 11 2010 vuntz@opensuse.org
- Update to version 0.1.13:
  + Silence more debug messages
  + Add a key file backend and linking support
  + Improve how we find the telepathy-glib Vala bindings
  + Improve our syncing behaviour to not overwrite aliases, groups,
    etc. as much as possible
* Fri Aug  6 2010 vuntz@opensuse.org
- Initial folks package, for version 0.1.12.
